@@ -7,10 +7,9 @@ import blurredface_sts_test
 import os
 import pkg_resources
 
+
 def prinfPath():{
-    print(os.path.dirname(os.path.realpath(__file__)))
-parent = os.path.dirname(os.path.realpath(__file__))
-print("!!! " + parent + "haarcascades/haarcascade_frontalface_default.xml")
+    print("!!! " + os.path.dirname(os.path.realpath(__file__)) + "haarcascades/haarcascade_frontalface_default.xml"),
 }
 
 #打码函数
